CognitoAdminCreateUserResult class

Result container for AdminCreateUser operations

Constructors

CognitoAdminCreateUserResult(Map<String, dynamic>? json)
Creates a result with the raw API response
const

Properties

hashCode int
The hash code for this object.
no setterinherited
json Map<String, dynamic>?
Raw JSON response from Cognito
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user Map<String, dynamic>?
Convenience accessor for the User object in the response
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited