consumers/cognito_admin_update_auth_event_feedback_consumer library

Classes

CognitoAdminUpdateAuthEventFeedbackBuilder
Builder class for constructing AdminUpdateAuthEventFeedback requests with a fluent interface pattern.
CognitoAdminUpdateAuthEventFeedbackConsumer
Consumer class that provides a reusable interface for executing AdminUpdateAuthEventFeedback operations with shared configuration.

Typedefs

CognitoAdminUpdateAuthEventFeedbackConsumerFn = void Function(CognitoAdminUpdateAuthEventFeedbackBuilder b)
Callback signature used to configure a feedback request builder.