CognitoHttpClient class abstract
Abstract interface for making authenticated HTTP requests to AWS Cognito.
Implementations of this interface must handle:
- Constructing the proper Cognito endpoint URL
- Signing requests with AWS SigV4 authentication
- Setting required Cognito-specific headers
- Sending JSON payloads via POST
This provides a consistent interface that can be implemented by different HTTP client implementations while maintaining the required AWS Cognito authentication and request formatting.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
post(
{required String region, required String xAmzTarget, required Map< String, dynamic> payload, Map<String, String> ? additionalHeaders, Duration? timeout}) → Future<CognitoHttpResponse> - Makes a signed POST request to the Cognito service.
-
send(
{required String service, required String target, required String region, required Map< String, dynamic> payload, required Duration timeout, Map<String, String> ? headers}) → Future<CognitoHttpResponse> -
Convenience method that matches the
send(...)signature used by request classes. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited